@@ -1,6 +1,6 @@
 package Code::TidyAll::SVN::Util;
 BEGIN {
-  $Code::TidyAll::SVN::Util::VERSION = '0.05';
+  $Code::TidyAll::SVN::Util::VERSION = '0.06';
 }
 use Cwd qw(realpath);
 use IPC::System::Simple qw(capturex);
@@ -16,7 +16,7 @@ sub svn_uncommitted_files {
     $dir = realpath($dir);
     my $output = capturex( "svn", "status", $dir );
     my @lines = grep { /^[AM]/ } split( "\n", $output );
-    my (@files) = ( $output =~ m{^[AM]\s+(.*)$}gm );
+    my (@files) = grep { -f } ( $output =~ m{^[AM]\s+(.*)$}gm );
     return @files;
 }
 
